Bomcheck Help

# bomcheckgui help

- Introduction
- How to run bomcheckgui
- How to copy & paste from the CAD BOM Table into ERP

## Introduction

Bomcheck is a command line interface (cli) program that can be run with the Command Prompt Terminal (cmd.exe). Bomcheckgui is a wrapper of bomcheck that provides graphical user interface (gui) for bomcheck. That is, bomcheckgui runs the bomcheck program in the background.

## How to run bomcheckgui:

Start bomcheckgui and then drag and drop the BOM files that you want to be evaluated onto bomcheckgui's main window. File names that do not end with _sw.xlsx or sl_xlsx will be ignored. Files that contain a tilde character, ~, will also be ignored. Optionally drag and drop a directory that contains the BOM files.

Press the green triangle icon to have your BOMs analyzed. Results can be saved to a text file. For more information about viewing the text files, see bomcheck's help.

To clear the list of files in the drop area, click the clear button, i.e. the eraser icon

Click on the folder icon to open the folder from which BOM data was last evaluated.